OC.L10N.register(
    "news",
    {
    "Saved" : "已儲存",
    "Download" : "下載",
    "Close" : "關閉",
    "Language" : "語言",
    "from" : "由",
    "Description" : "描述",
    "Refresh" : "重新整理",
    "Web address" : "網絡地址",
    "Folder" : "資料夾",
    "New folder" : "新文件夾",
    "Folder name" : "資料夾名稱",
    "Credentials" : "Credentials",
    "Username" : "用戶名稱",
    "Password" : "密碼",
    "Create" : "新增",
    "Rename" : "重新命名",
    "Newest first" : "最新",
    "Oldest first" : "最舊",
    "Delete" : "刪除",
    "Settings" : "設定",
    "Import" : "導入",
    "Export" : "輸出",
    "Help" : "幫助",
    "Documentation" : "文件"
},
"nplurals=1; plural=0;");
